/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at
 * trunk/opends/resource/legal-notices/OpenDS.LICENSE
 * or https://OpenDS.dev.java.net/OpenDS.LICENSE.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at
 * trunk/opends/resource/legal-notices/OpenDS.LICENSE.  If applicable,
 * add the following below this CDDL HEADER, with the fields enclosed
 * by brackets "[]" replaced with your own identifying information:
 *      Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 *
 *
 *      Copyright 2008 Sun Microsystems, Inc.
 */
package org.opends.server.admin.std.client;



import org.opends.server.admin.ConfigurationClient;
import org.opends.server.admin.IllegalPropertyValueException;
import org.opends.server.admin.ManagedObjectDefinition;
import org.opends.server.admin.PropertyIsReadOnlyException;
import org.opends.server.admin.std.server.WorkflowElementCfg;



/**
 * A client-side interface for reading and modifying Workflow Element
 * settings.
 * <p>
 * Workflow Elements implement a single processing step in a Work
 * Flow.
 */
public interface WorkflowElementCfgClient extends ConfigurationClient {

  /**
   * Get the configuration definition associated with this Workflow Element.
   *
   * @return Returns the configuration definition associated with this Workflow Element.
   */
  ManagedObjectDefinition<? extends WorkflowElementCfgClient, ? extends WorkflowElementCfg> definition();



  /**
   * Gets the "enabled" property.
   * <p>
   * Indicates whether the Workflow Element is enabled for use in the
   * server.
   * <p>
   * If a Workflow Element is not enabled, then its contents are not
   * accessible when processing operations.
   *
   * @return Returns the value of the "enabled" property.
   */
  Boolean isEnabled();



  /**
   * Sets the "enabled" property.
   * <p>
   * Indicates whether the Workflow Element is enabled for use in the
   * server.
   * <p>
   * If a Workflow Element is not enabled, then its contents are not
   * accessible when processing operations.
   *
   * @param value The value of the "enabled" property.
   * @throws IllegalPropertyValueException
   *           If the new value is invalid.
   */
  void setEnabled(boolean value) throws IllegalPropertyValueException;



  /**
   * Gets the "java-class" property.
   * <p>
   * Specifies the fully-qualified name of the Java class that
   * provides the Workflow Element implementation.
   *
   * @return Returns the value of the "java-class" property.
   */
  String getJavaClass();



  /**
   * Sets the "java-class" property.
   * <p>
   * Specifies the fully-qualified name of the Java class that
   * provides the Workflow Element implementation.
   *
   * @param value The value of the "java-class" property.
   * @throws IllegalPropertyValueException
   *           If the new value is invalid.
   */
  void setJavaClass(String value) throws IllegalPropertyValueException;



  /**
   * Gets the "workflow-element-id" property.
   * <p>
   * Provides a name that identifies the associated Workflow Element .
   * <p>
   * The name must be unique among all Workflow Elements in the
   * server.
   *
   * @return Returns the value of the "workflow-element-id" property.
   */
  String getWorkflowElementId();



  /**
   * Sets the "workflow-element-id" property.
   * <p>
   * Provides a name that identifies the associated Workflow Element .
   * <p>
   * The name must be unique among all Workflow Elements in the
   * server.
   * <p>
   * This property is read-only and can only be modified during
   * creation of a Workflow Element.
   *
   * @param value The value of the "workflow-element-id" property.
   * @throws IllegalPropertyValueException
   *           If the new value is invalid.
   * @throws PropertyIsReadOnlyException
   *           If this Workflow Element is not being initialized.
   */
  void setWorkflowElementId(String value) throws IllegalPropertyValueException, PropertyIsReadOnlyException;

}
